pub struct MemoryStore { /* private fields */ }Expand description
Append-and-update key-value memory store.
Implementations
Sourceimpl MemoryStore
impl MemoryStore
pub fn new() -> Self
Sourcepub fn store(&mut self, key: &str, value: Value, tags: &[&str])
pub fn store(&mut self, key: &str, value: Value, tags: &[&str])
Store value under key. Overwrites any existing entry.
Sourcepub fn get(&mut self, key: &str) -> Option<&MemoryEntry>
pub fn get(&mut self, key: &str) -> Option<&MemoryEntry>
Get an entry by key, updating its access metadata.
Sourcepub fn peek(&self, key: &str) -> Option<&MemoryEntry>
pub fn peek(&self, key: &str) -> Option<&MemoryEntry>
Get an entry by key without updating access metadata.
Sourcepub fn all(&self) -> Vec<&MemoryEntry>
pub fn all(&self) -> Vec<&MemoryEntry>
All entries, sorted by key.
Sourcepub fn by_tag(&self, tag: &str) -> Vec<&MemoryEntry>
pub fn by_tag(&self, tag: &str) -> Vec<&MemoryEntry>
Entries matching a specific tag.
pub fn len(&self) -> usize
pub fn is_empty(&self) -> bool